pub enum KeepAliveFlag {
BalancerTarget,
BalancerState,
}Expand description
Individual flags that can be set in a KeepAliveMessage.
Variants
BalancerTarget
The additional_data field contains load balancer target information.
The value of additional_data represents the optimal number of SURBs that the
Session Initiator wishes to maintain at the Session Recipient.
Mutually exclusive with BalancerState.
BalancerState
The additional_data field contains load balancer state information.
The value of additional_data represents the current number of SURBs
that the Session Recipient estimates to have.
Mutually exclusive with BalancerTarget.