pub type KeepAliveFlags = FlagSet<KeepAliveFlag>;Expand description
Flags that can be sent via the KeepAliveMessage.
The flags can define the meaning of the additional_data field.
Aliased Type
pub struct KeepAliveFlags(/* private fields */);pub type KeepAliveFlags = FlagSet<KeepAliveFlag>;Flags that can be sent via the KeepAliveMessage.
The flags can define the meaning of the additional_data field.
pub struct KeepAliveFlags(/* private fields */);